## About Kubernetes Community Days

Kubernetes Community Days (KCDs) are community-organized events that gather adopters and technologists from open source and cloud native communities for education, collaboration, and networking. KCDs are supported by the [Cloud Native Computing Foundation](https://cncf.io) (CNCF). These fun, locally-defined events help grow and sustain the Kubernetes community.

We'd like to thank [DevOpsDays](https://devopsdays.org) and [OpenStack Days](https://www.openstack.org/community/events/openstackdays) for providing some of the core ideas and content for this document.

KCDs can be in person, virtual, or hybrid. In person is strongly encouraged when possible. Virtual events are run on the [Cloud Native Community Groups](https://community.cncf.io/) platform, powered by [Bevy](https://www.bevy.com/). 

## Interested in Hosting a Kubernetes Community Day?

Any city or region can host a Kubernetes Community Day. Each local KCD event team handles its own sponsorships, registration, and logistics. Check if there is a KCD event scheduled in your area on the [issue board](https://github.com/cncf/kubernetes-community-days/projects/2). If there *is* already an event scheduled, you can reach out to the organizers and offer to help. The CNCF supports KCDs with guidance and event promotion via CNCF newsletters, blog posts, and social media channels.

This quick start guide covers all aspects of holding a successful event. Please keep in mind that Kubernetes Community Days are:

* **Primarily for community engagement**. Organizers and speakers must avoid vendor pitches.
* **Inclusive**. Organizers must make reasonable efforts to work with others, regardless of their organizational affiliation.

## Timline

Here is a [planning timeline](https://docs.google.com/spreadsheets/d/1bvCiyyDut1seSnBE6pzVevcJkXLeWbxbncvhFsyY8PI/edit#gid=0) you can review, then make a copy and edit. We have noted aspects that are for in-person events vs online only.

## Assembling Your Team

The first step towards a successful event is building a team. Look for potential team members in local user groups and Meetups, such as the [CNCF Community Groups](https://community.cncf.io/), or online in the public Kubernetes slack or other related online communities.

Check the GitHub Kubernetes Community Days [issue board](https://github.com/cncf/kubernetes-community-days/projects/2) to see if others have expressed interest in organizing an event in your area. If there are no issues for your area, create an issue asking if others are interested in organizing an event with you. After your team is assembled, we encourage you to have regular meetings for planning purposes. If you would like to record your meetings or need a conference line, CNCF can provide a Zoom URL. Please contact a Core Organizer for access or to learn more.

We recommend assigning the following responsibilities to one or two members of your organizing team:

* [Finance and budgeting](/planning/budget-finances.md)
* [Marketing and promotion](/planning/marketing-promotion.md) 
* [Sponsors](/sponsor-resources/sponsorships-faq.md)
* [Call for Proposals (CFP) and schedule](/speaker-resources/cfp.md)
* Website updates
* [Registration](/planning/registration.md)
* Venue, catering, local activities, and the hotel
* T-shirts and other swag
* Evening event logistics

## Getting Started Checklist

Once you have found and organized your team through Github issues, it it time to start planning!

* Verify that no other Kubernetes Community Day events are planned in your local area
* Have a minimum of 3 local organizers (5 is recommended) from at least 3 different organizations. Each organizer needs to live in or just outside of the KCD location.
* Have a minimum of 3 sponsors (Not required for virtual only events) ** 
* Make sure that at least one organizer is an employee of a CNCF [member](https://www.cncf.io/about/members/), an [Ambassador](https://www.cncf.io/people/ambassadors/), or a CNCF project [maintainer](http://maintainers.cncf.io/)
* Have a method to accept payments (sponsorships, tickets) and make payments (catering, A/V, other costs)
* Verify that all organizers have agreed to these event guidelines and to abide by the Kubernetes Community Day [Code of Conduct](code-of-conduct.md)
* Schedule an event date a minimum of 6 months after  you file your event request with CNCF request submission,  (9 months prior is preferable)
* Agree to use [Cloud Native Community Groups](https://community.cncf.io/) for [registration and ticketing](https://help.bevylabs.com/article/369-manage-event-ticketing)*
* Agree to use [Cloud Native Community Groups](https://community.cncf.io/) for organizing the program page*
* Agree to use [SM Apply](https://apply.surveymonkey.com/) for the CFP*
* Share CNCF Slack usernames for all organizers to be added to #KCD-organizers channel
* Create Twitter handle for specific KCD event (like @KCD-BouvetIsland) except for countries like China and Korea where Twitter is not used

Once your team meets these criteria, you can create a GitHub [issue](https://github.com/cncf/kubernetes-community-days/issues/) to notify CNCF that you wish to be officially recognized. Your organizing team will be invited to the [#kcd-organizers](https://cloud-native.slack.com/messages/GN6R2PV1A) private Slack channel where you can connect with other Kubernetes Community Days organizers around the world. At this time, the Core Organizers will also grant you access to our preferred tools and create email aliases (for general organizers and sponsorships). You can then begin creating your website and the Bevy event platform. Follow instructions under "Event Creation" in the [Bevy Conference Success](https://docs.google.com/spreadsheets/d/1FeUB6beZAVeR8ViVIR-_mPUSxKHsynDc9XCIvx1roqc/edit#gid=698508546) plan. 

* Where our standard tools are blocked, CNCF will work with KCD organizers to determine alternatives. 

** For the launch, we want to ensure that each KCD is successful. Part of ensuring the success of the event is to have the first 3 sponsors committed. We acknowledge requiring KCD Organizers to have 3 sponsors committed prior to the approval of your event can be challenging.

## Event Details 

Events may be developer-focused or they can cover on business issues and cloud strategy. Attendance averages 100-400 people. Most start small and grow slowly. Again, Kubernetes Community Days are not to be used for commercial pitches. Any platforms or tools you are describing the need to be open source. That said, many (most?) talks will be about how companies relied on open source technologies to improve their processes. Event profits must be reinvested in future years. Organizers should be reimbursed for their actual expenses reimbursed, but not their time.

Other considerations:

* Encourage bold, innovative, thought-provoking subjects
* Events usually have four 30-minute talks per day
* Open space sessions are generated, voted on and scheduled during the conference - not ahead of time.
* The event must be at least one day long
* Lower-prices for early-bird registration are recommended
* Registration and sponsorship needs to be available to anyone until  available capacity sells out
* Encourage interaction and think about ways to create this
* The attendee list may not be used for commercial or marketing purposes. It may only be used to advertise that specific Kubernetes Community Day or further iterations of it. The list may not be shared with third parties who are not directly involved in organizing the event. Please review the [Privacy Policy Statement](https://www.linuxfoundation.org/privacy/).
* Sponsors are allowed to collect attendee information at their tables. 

## Logos and Trademarks

Once your event and name have been accepted, you are authorized by CNCF to use that name (e.g., Kubernetes Community Days Bouvet Island). Please design a custom logo for your event. **The logo is not permitted to include the Kubernetes Wheel (in whole or in part).** The event logo must include the event name. You are welcome to include the CNCF logo in your event logo and graphics; you’re also welcome to use [Phippy](https://phippy.io/) and friends (high-res versions available in the artwork [repo](https://github.com/cncf/artwork/blob/master/examples/other.md#phippy--friends-group-logos).

Please post your logo in SVG format, as [explained](https://www.cncf.io/blog/2019/07/17/what-image-formats-should-you-be-using-in-2019/) in this blog post.

All events must be called “Kubernetes Community Days LOCATION”, e.g. Kubernetes Community Days Bouvet Island.

## Kubernetes Community Days Planning Tools

* [Conference Planning Action Items and Checklist](https://docs.google.com/spreadsheets/d/1bvCiyyDut1seSnBE6pzVevcJkXLeWbxbncvhFsyY8PI/edit) (Google Spreadsheet) a template for check-in meetings to keep everyone is on task. 
* [Sponsorship Letter](/sponsor-resources/letter-prospecting-sponsors.md) to send to prospective sponsors.
* [Sponsorship Prospectus](/sponsor-resources/) (to send to prospective sponsors and post on the event website.)
* [Sample Invoice](https://docs.google.com/document/d/1Rbc8hvBgbO55asEQzzAHkpvSU2ogl52NmWq1-NhBYdY/edit) (Google Spreadsheet) to invoice sponsors.
* [Sample Call for Proposals](/speaker-resources/cfp.md) to recruit speakers.
* [CNCF Speakers' Bureau](https://www.cncf.io/speakers/) to connect with expert speakers within the cloud native ecosystem.
* [CNCF Digital Assets](https://github.com/cncf/artwork) for  event promotions.
* [How to work with the Bevy platform](https://github.com/cncf/kubernetes-community-days/blob/main/planning/platform-help.md)
* SM Apply [Help Center](https://help.smapply.io/hc/en-us) and [Training videos](https://help.smapply.io/hc/en-us/categories/115000187973-Implementation-Training-Videos)
* How to deal with [disagreements between organizers](planning/organizer-mediation.md
* [FAQ](/planning/faq.md)

## Core Organizers

The current organizers are Bill Mulligan and Ihor Dvoretskyi.

You can reach us at kcd@cncf.io or on the CNCF Slack. Create a free [account](https://slack.cncf.io) and come to the [#kcd-formation](https://cloud-native.slack.com/messages/CN6LBV16G) channel.

